@@ -121,6 +121,20 @@ Allows you to set a new maximum number of children to maintain.
 You can call this method to wait for all the processes which have been
 forked. This is a blocking wait.
 
+=item reap_finished_children
+
+This is a non-blocking call to reap children and execute callbacks independent
+of calls to "start" or "wait_all_children". Use this in scenarios where "start"
+is called infrequently but you would like the callbacks executed quickly.
+
+=item is_parent
+
+Returns C<true> if within the parent or C<false> if within the child.
+
+=item is_child
+
+Returns C<true> if within the child or C<false> if within the parent.
+
 =item max_procs 
 
 Returns the maximal number of processes the object will fork.
@@ -547,7 +561,7 @@ use Carp;
 
 use strict;
 use vars qw($VERSION);
-$VERSION="1.13";
+$VERSION="1.14";
 $VERSION = eval $VERSION;
 
 sub new {
@@ -636,6 +650,7 @@ sub wait_children {
 };
 
 *wait_childs=*wait_children; # compatibility
+*reap_finished_children=*wait_children; # behavioral synonym for clarity
 
 sub wait_one_child {
   my ($s,$par)=@_;
@@ -681,6 +696,10 @@ sub wait_all_children {
 
 sub max_procs { $_[0]->{max_proc}; }
 
+sub is_child  { $_[0]->{in_child} }
+
+sub is_parent { !$_[0]->{in_child} }
+
 sub running_procs {
     my $self = shift;
 
